ChangeLog — The yt Project 3.2-dev documentation

# ChangeLog

This is a non-comprehensive log of changes to yt over its many releases.

## Contributors

The CREDITS file contains the most up-to-date list of everyone who has contributed to the yt source code.

## Version 3.1

This is a scheduled feature release. Below are the itemized, aggregate changes since version 3.0.

### Major changes:

- The RADMC-3D export analysis module has been updated. PR 1358, PR 1332.
- Performance improvements for grid frontends. PR 1350. PR 1382, PR 1322.
- Added a frontend for Dark Matter-only NMSU Art simulations. PR 1258.
- The absorption spectrum generator has been updated. PR 1356.
- The PerspectiveCamera has been updated and a new SphericalCamera has been added. PR 1346, PR 1299.
- The unit system now supports unit equivalencies and has improved support for MKS units. See Unit Equivalencies. PR 1291, PR 1286.
- Data object selection can now be chained, allowing selecting based on multiple constraints. PR 1264.
- Added the ability to manually override the simulation unit system. PR 1236.
- The documentation has been reorganized and has seen substantial improvements. PR 1383, PR 1373, PR 1364, PR 1351, PR 1345. PR 1333, PR 1342, PR 1338, PR 1330, PR 1326, PR 1323, PR 1315, PR 1305, PR 1289, PR 1276.

### Minor or bugfix changes:

- The Ampere unit now accepts SI prefixes. PR 1393.
- The Gadget InternalEnergy and StarFormationRate fields are now read in with the correct units. PR 1392, PR 1379.
- Substantial improvements for the PPVCube analysis module and support for FITS dataset. PR 1390, PR 1367, PR 1347, PR 1326, PR 1280, PR 1336.
- The center of a PlotWindow plot can now be set to the maximum or minimum of any field. PR 1280.
- Fixes for yt testing infrastructure. PR 1388, PR 1348.
- Projections are now performed using an explicit path length field for all coordinate systems. PR 1307.
- An example notebook for simulations using the OWLS data format has been added to the documentation. PR 1386.
- Fix for the camera.draw_line function. PR 1380.
- Minor fixes and improvements for yt plots. PR 1376, PR 1374, PR 1288, PR 1290.
- Significant documentation reorganization and improvement. PR 1375, PR 1359.
- Fixed a conflict in the CFITSIO library used by the x-ray analysis module. PR 1365.
- Miscellaneous code cleanup. PR 1371, PR 1361.
- yt now hooks up to the python logging infrastructure in a more standard fashion, avoiding issues with yt logging showing up with using other libraries. PR 1355, PR 1362, PR 1360.
- The docstring for the projection data object has been corrected. PR 1366
- A bug in the calculation of the plot bounds for off-axis slice plots has been fixed. PR 1357.
- Improvements for the yt-rockstar interface. PR 1352, PR 1317.
- Fix issues with plot positioning with saving to postscript or encapsulated postscript. PR 1353.
- It is now possible to supply a default value for get_field_parameter. PR 1343.
- A bug in the interpretation of the units of RAMSES simulations has been fixed. PR 1335.
- Plot callbacks are now only executed once before the plot is saved. PR 1328.
- Performance improvements for smoothed covering grid alias fields. PR 1331.
- Improvements and bugfixes for the halo analysis framework. PR 1349, PR 1325.
- Fix issues with the default setting for the `center` field parameter. PR 1327.
- Avoid triggering warnings in numpy and matplotlib. PR 1334, PR 1300.
- Updates for the field list reference. PR 1344, PR 1321, PR 1318.
- yt can now be run in parallel on a subset of available processors using an MPI subcommunicator. PR 1340
- Fix for incorrect units when loading an Athena simulation as a time series. PR 1341.
- Improved support for Enzo 3.0 simulations that have not produced any active particles. PR 1329.
- Fix for parsing OWLS outputs with periods in the file path. PR 1320.
- Fix for periodic radius vector calculation. PR 1311.
- Improvements for the Maestro and Castro frontends. PR 1319.
- Clump finding is now supported for more generic types of data. PR 1314
- Fix unit consistency issue when mixing dimensionless unit symbols. PR 1300.
- Improved memory footprint in the photon_simulator. PR 1304.
- Large grids in Athena datasets produced by the join_vtk script can now be optionally split, improving parallel performance. PR 1304.
- Slice plots now accept a `data_source` keyword argument. PR 1310.
- Corrected inconsistent octrees in the RAMSES frontend. PR 1302
- Nearest neighbor distance field added. PR 1138.
- Improvements for the ORION2 frontend. PR 1303
- Enzo 3.0 frontend can now read active particle attributes that are arrays of any shape. PR 1248.
- Answer tests added for halo finders. PR 1253
- A `setup_function` has been added to the LightRay initializer. PR 1295.
- The SPH code frontends have been reorganized into separate frontend directories. PR 1281.
- Fixes for accessing deposit fields for FLASH data. PR 1294
- Added tests for ORION datasets containing sink and star particles. PR 1252
- Fix for field names in the particle generator. PR 1278.
- Added wrapper functions for numpy array manipulation functions. PR 1287.
- Added support for packed HDF5 Enzo datasets. PR 1282.

## Version 3.0

This release of yt features an entirely rewritten infrastructure for data ingestion, indexing, and representation. While past versions of yt were focused on analysis and visualization of data structured as regular grids, this release features full support for particle (discrete point) data such as N-body and SPH data, irregular hexahedral mesh data, and data organized via octrees. This infrastructure will be extended in future versions for high-fidelity representation of unstructured mesh datasets.

Highlighted changes in yt 3.0:

> - Units now permeate the code base, enabling self-consistent unit transformations of all arrays and quantities returned by yt.
> - Particle data is now supported using a lightweight octree. SPH data can be smoothed onto an adaptively-defined mesh using standard SPH smoothing
> - Support for octree AMR codes
> - Preliminary Support for non-Cartesian data, such as cylindrical, spherical, and geographical
> - Revamped analysis framework for halos and halo catalogs, including direct ingestion and analysis of halo catalogs of several different formats
> - Support for multi-fluid datasets and datasets containing multiple particle types
> - Flexible support for dynamically defining new particle types using filters on existing particle types or by combining different particle types.
> - Vastly improved support for loading generic grid, AMR, hexahedral mesh, and particle without hand-coding a frontend for a particular data format.
> - New frontends for ART, ARTIO, Boxlib, Chombo, FITS, GDF, Subfind, Rockstar, Pluto, RAMSES, SDF, Gadget, OWLS, PyNE, Tipsy, as well as rewritten frontends for Enzo, FLASH, Athena, and generic data.
> - First release to support installation of yt on Windows
> - Extended capabilities for construction of simulated observations, and new facilities for analyzing and visualizing FITS images and cube data
> - Many performance improvements

This release is the first of several; while most functionality from the previous generation of yt has been updated to work with yt 3.0, it does not yet have feature parity in all respects. While the core of yt is stable, we suggest the support for analysis modules and volume rendering be viewed as a late-stage beta, with a series of additional releases (3.1, 3.2, etc) appearing over the course of the next year to improve support in these areas.

For a description of how to bring your 2.x scripts up to date to 3.0, and a summary of common gotchas in this transition, please see What’s New and Different in yt 3.0?.

## Version 2.6

This is a scheduled release, bringing to a close the development in the 2.x series. Below are the itemized, aggregate changes since version 2.5.

Major changes:

> - yt is now licensed under the 3-clause BSD license.
> - HEALPix has been removed for the time being, as a result of licensing incompatibility.
> - The addition of a frontend for the Pluto code
> - The addition of an OBJ exporter to enable transparent and multi-surface exports of surfaces to Blender and Sketchfab
> - New absorption spectrum analysis module with documentation
> - Adding ability to draw lines with Grey Opacity in volume rendering
> - Updated physical constants to reflect 2010 CODATA data
> - Dependency updates (including IPython 1.0)
> - Better notebook support for yt plots
> - Considerably (10x+) faster kD-tree building for volume rendering
> - yt can now export to RADMC3D
> - Athena frontend now supports Static Mesh Refinement and units ( http://hub.yt-project.org/nb/7l1zua )
> - Fix long-standing bug for plotting arrays with range of zero
> - Adding option to have interpolation based on non-uniform bins in interpolator code
> - Upgrades to most of the dependencies in the install script
> - ProjectionPlot now accepts a data_source keyword argument

Minor or bugfix changes:

> - Fix for volume rendering on the command line
> - map_to_colormap will no longer return out-of-bounds errors
> - Fixes for dds in covering grid calculations
> - Library searching for build process is now more reliable
> - Unit fix for “VorticityGrowthTimescale” field
> - Pyflakes stylistic fixes
> - Number density added to FLASH
> - Many fixes for Athena frontend
> - Radius and ParticleRadius now work for reduced-dimensionality datasets
> - Source distributions now work again!
> - Athena data now 64 bits everywhere
> - Grids displays on plots are now shaded to reflect the level of refinement
> - show_colormaps() is a new function for displaying all known colormaps
> - PhasePlotter by default now adds a colormap.
> - System build fix for POSIX systems
> - Fixing domain offsets for halo centers-of-mass
> - Removing some Enzo-specific terminology in the Halo Mass Function
> - Addition of coordinate vectors on volume render
> - Pickling fix for extracted regions
> - Addition of some tracer particle annotation functions
> - Better error message for “yt” command
> - Fix for radial vs poloidal fields
> - Piernik 2D data handling fix
> - Fixes for FLASH current redshift
> - PlotWindows now have a set_font function and a new default font setting
> - Colorbars less likely to extend off the edge of a PlotWindow
> - Clumps overplotted on PlotWindows are now correctly contoured
> - Many fixes to light ray and profiles for integrated cosmological analysis
> - Improvements to OpenMP compilation
> - Typo in value for km_per_pc (not used elsewhere in the code base) has been fixed
> - Enable parallel IPython notebook sessions ( http://hub.yt-project.org/nb/qgn19h )
> - Change (~1e-6) to particle_density deposition, enabling it to be used by FLASH and other frontends
> - Addition of is_root function for convenience in parallel analysis sessions
> - Additions to Orion particle reader
> - Fixing TotalMass for case when particles not present
> - Fixing the density threshold or HOP and pHOP to match the merger tree
> - Reason can now plot with latest plot window
> - Issues with VelocityMagnitude and aliases with velo have been corrected in the FLASH frontend
> - Halo radii are calculated correctly for domains that do not start at 0,0,0.
> - Halo mass function now works for non-Enzo frontends.
> - Bug fixes for directory creation, typos in docstrings
> - Speed improvements to ellipsoidal particle detection
> - Updates to FLASH fields
> - CASTRO frontend bug fixes
> - Fisheye camera bug fixes
> - Answer testing now includes plot window answer testing
> - Athena data serialization
> - load_uniform_grid can now decompose dims >= 1024. (#537)
> - Axis unit setting works correctly for unit names (#534)
> - ThermalEnergy is now calculated correctly for Enzo MHD simulations (#535)
> - Radius fields had an asymmetry in periodicity calculation (#531)
> - Boolean regions can now be pickled (#517)

## Version 2.5

Many below-the-surface changes happened in yt 2.5 to improve reliability, fidelity of the answers, and streamlined user interface. The major change in this release has been the immense expansion in testing of yt. We now have over 2000 unit tests (run on every commit, thanks to both Kacper Kowalik and Shining Panda) as well as answer testing for FLASH, Enzo, Chombo and Orion data.

The Stream frontend, which can construct datasets in memory, has been improved considerably. It’s now easier than ever to load data from disk. If you know how to get volumetric data into Python, you can use either the `load_uniform_grid` function or the `load_amr_grid` function to create an in-memory dataset that yt can analyze.

yt now supports the Athena code.

yt is now focusing on providing first class support for the IPython notebook. In this release, plots can be displayed inline. The Reason HTML5 GUI will be merged with the IPython notebook in a future release.

> - SciPy can now be installed
> - Rockstar can now be installed
> - Dependencies can be updated with “yt update –all”
> - Cython has been upgraded to 0.17.1
> - Python has been upgraded to 2.7.3
> - h5py has been upgraded to 2.1.0
> - hdf5 has been upgraded to 1.8.9
> - matplotlib has been upgraded to 1.2.0
> - IPython has been upgraded to 0.13.1
> - Forthon has been upgraded to 0.8.10
> - nose has been added
> - sympy has been added
> - python-hglib has been added

We’ve also improved support for installing on OSX, Ubuntu and OpenSUSE.

> - Nearly 200 pull requests and over 1000 changesets have been merged since yt 2.4 was release on August 2nd, 2012.
> - numpy is now imported as np, not na. na will continue to work for the foreseeable future.
> - You can now get a yt cheat sheet <http://yt-project.org/docs/2.5/cheatsheet.pdf>!
> - yt can now load simulation data created by Athena.
> - The Rockstar halo finder can now be installed by the install script
> - SciPy can now be installed by the install script
> - Data can now be written out in two ways:
>   - Sidecar files containing expensive derived fields can be written and implicitly loaded from.
>   - GDF files, which are portable yt-specific representations of full simulations, can be created from any dataset. Work is underway on a pure C library that can be linked against to load these files into simulations.
> - The “Stream” frontend, for loading raw data in memory, has been greatly expanded and now includes initial conditions generation functionality, particle fields, and simple loading of AMR grids with `load_amr_grids`.
> - Spherical and Cylindrical fields have been sped up and made to have a uniform interface. These fields can be the building blocks of more advanced fields.
> - Coordinate transformations have been sped up and streamlined. It is now possible to convert any scalar or vector field to a new cartesian, spherical, or cylindrical coordinate system with an arbitrary orientation. This makes it possible to do novel analyses like profiling the toroidal and poloidal velocity as a function of radius in an inclined disk.
> - Many improvements to the EnzoSimulation class, which can now find many different types of data.
> - Image data is now encapsulated in an ImageArray class, which carries with it provenance information about its trajectory through yt.
> - Streamlines now query at every step along the streamline, not just at every cell.
> - Surfaces can now be extracted and examined, as well as uploaded to Sketchfab.com for interactive visualization in a web browser.
> - allsky_projection can now accept a datasource, making it easier to cut out regions to examine.
> - Many, many improvements to PlotWindow. If you’re still using PlotCollection, check out `ProjectionPlot`, `SlicePlot`, `OffAxisProjectionPlot` and `OffAxisSlicePlot`.
> - PlotWindow can now accept a timeseries instead of a dataset.
> - Many fixes for 1D and 2D data, especially in FLASH datasets.
> - Vast improvements to the particle file handling for FLASH datasets.
> - Particles can now be created ex nihilo with CICSample_3.
> - Rockstar halo finding is now a targeted goal. Support for using Rockstar has improved dramatically.
> - Increased support for tracking halos across time using the FOF halo finder.
> - The command `yt notebook` has been added to spawn an IPython notebook server, and the `yt.imods` module can replace `yt.mods` in the IPython Notebook to enable better integration.
> - Metallicity-dependent X-ray fields have now been added.
> - Grid lines can now be added to volume renderings.
> - Volume rendering backend has been updated to use an alpha channel, fixing parallel opaque volume renderings. This also enables easier blending of multiple images and annotations to the rendering. Users are encouraged to look at the capabilities of the `ImageArray` for writing out renders, as updated in the cookbook examples. Volume renders can now be saved with an arbitrary background color.
> - Periodicity, or alternately non-periodicity, is now a part of radius calculations.
> - The AMRKDTree has been rewritten. This allows parallelism with other than power-of-2 MPI processes, arbitrary sets of grids, and splitting of unigrids.
> - Fixed Resolution Buffers and volume rendering images now utilize a new ImageArray class that stores information such as data source, field names, and other information in a .info dictionary. See the `ImageArray` docstrings for more information on how they can be used to save to a bitmap or hdf5 file.

## Version 2.4

The 2.4 release was particularly large, encompassing nearly a thousand changesets and a number of new features.

To help you get up to speed, we’ve made an IPython notebook file demonstrating a few of the changes to the scripting API. You can download it here.

> - Threaded volume renderer, completely refactored from the ground up for speed and parallelism.

> - The Plot Window (see Slices & Projections) is now fully functional! No more PlotCollections, and full, easy access to Matplotlib axes objects.

> - Many improvements to Time Series analysis:
>     - EnzoSimulation now integrates with TimeSeries analysis!
>     - Auto-parallelization of analysis and parallel iteration
>     - Memory usage when iterating over datasets reduced substantially
> - Many improvements to Reason, the yt GUI
>     - Addition of “yt reason” as a startup command
>     - Keyboard shortcuts in projection & slice mode: z, Z, x, X for zooms, hjkl, HJKL for motion
>     - Drag to move in projection & slice mode
>     - Contours and vector fields in projection & slice mode
>     - Color map selection in projection & slice mode
>     - 3D Scene

> - Integration with the all new yt Hub ( http://hub.yt-project.org/ ): upload variable resolution projections, slices, project information, vertices and plot collections right from the yt command line!

> - `ProjectionPlot` and `SlicePlot` supplant the functionality of PlotCollection.
> - Camera path creation from keyframes and splines
> - Ellipsoidal data containers and ellipsoidal parameter calculation for halos
> - PyX and ZeroMQ now available in the install script
> - Consolidation of unit handling
> - HDF5 updated to 1.8.7, Mercurial updated to 2.2, IPython updated to 0.12
> - Preview of integration with Rockstar halo finder
> - Improvements to merger tree speed and memory usage
> - Sunrise exporter now compatible with Sunrise 4.0
> - Particle trajectory calculator now available!
> - Speed and parallel scalability improvements in projections, profiles and HOP
> - New Vorticity-related fields
> - Vast improvements to the ART frontend
> - Many improvements to the FLASH frontend, including full parameter reads, speedups, and support for more corner cases of FLASH 2, 2.5 and 3 data.
> - Integration of the Grid Data Format frontend, and a converter for Athena data to this format.
> - Improvements to command line parsing
> - Parallel import improvements on parallel filesystems (`from yt.pmods import *`)
> - proj_style keyword for projections, for Maximum Intensity Projections (`proj_style = "mip"`)
> - Fisheye rendering for planetarium rendering
> - Profiles now provide *_std fields for standard deviation of values
> - Generalized Orientation class, providing 6DOF motion control
> - parallel_objects iteration now more robust, provides optional barrier. (Also now being used as underlying iteration mechanism in many internal routines.)
> - Dynamic load balancing in parallel_objects iteration.
> - Parallel-aware objects can now be pickled.
> - Many new colormaps included
> - Numerous improvements to the PyX-based eps_writer module
> - FixedResolutionBuffer to FITS export.
> - Generic image to FITS export.
> - Multi-level parallelism for extremely large cameras in volume rendering
> - Light cone and light ray updates to fit with current best practices for parallelism

## Version 2.3

(yt 2.3 docs)
  - Multi-level parallelism
  - Real, extensive answer tests
  - Boolean data regions (see Combining Objects: Boolean Data Objects)
  - Isocontours / flux calculations (see 3D Surfaces and Sketchfab)
  - Field reorganization
  - PHOP memory improvements
  - Bug fixes for tests
  - Parallel data loading for RAMSES, along with other speedups and improvements there
  - WebGL interface for isocontours and a pannable map widget added to Reason
  - Performance improvements for volume rendering
  - Adaptive HEALPix support
  - Column density calculations (see Radial Column Density)
  - Massive speedup for 1D profiles
  - Lots more, bug fixes etc.
  - Substantial improvements to the documentation, including Using the Manual Plotting Interface and a revamped orientation.

## Version 2.2

(yt 2.2 docs)
  - Command-line submission to the yt Hub (http://hub.yt-project.org/)
  - Initial release of the web-based GUI Reason, designed for efficient remote usage over SSH tunnels
  - Absorption line spectrum generator for cosmological simulations (see Absorption Spectrum)
  - Interoperability with ParaView for volume rendering, slicing, and so forth
  - Support for the Nyx code
  - An order of magnitude speed improvement in the RAMSES support
  - Quad-tree projections, speeding up the process of projecting by up to an order of magnitude and providing better load balancing
  - “mapserver” for in-browser, Google Maps-style slice and projection visualization (see Mapserver - A Google-Maps-like Interface to your Data)
  - Many bug fixes and performance improvements
  - Halo loader

## Version 2.1

(yt 2.1 docs)
  - HEALPix-based volume rendering for 4pi, allsky volume rendering
  - libconfig is now included
  - SQLite3 and Forthon now included by default in the install script
  - Development guide has been lengthened substantially and a development bootstrap script (Submitting Changes) is now included.
  - Installation script now installs Python 2.7 and HDF5 1.8.6
  - iyt now tab-completes field names
  - Halos can now be stored on-disk much more easily between HaloFinding runs.
  - Halos found inline in Enzo can be loaded and merger trees calculated
  - Support for CASTRO particles has been added
  - Chombo support updated and fixed
  - New code contributions
  - Contour finder has been sped up by a factor of a few
  - Constrained two-point functions are now possible, for LOS power spectra
  - Time series analysis (Time Series Analysis) now much easier
  - Stream Lines now a supported 1D data type
  - Stream Lines now able to be calculated and plotted (Streamlines: Tracking the Trajectories of Tracers in your Data)
  - In situ Enzo visualization now much faster
  - “gui” source directory reorganized and cleaned up
  - Cython now a compile-time dependency, reducing the size of source tree updates substantially
  - `yt-supplemental` repository now checked out by default, containing cookbook, documentation, handy mercurial extensions, and advanced plotting examples and helper scripts.
  - Pasteboards now supported and available
  - Parallel yt efficiency improved by removal of barriers and improvement of collective operations

## Version 2.0

> - Major reorganization of the codebase for speed, ease of modification, and maintainability
> - Re-organization of documentation and addition of Orientation Session
> - Support for FLASH code
> - Preliminary support for MAESTRO, CASTRO, ART, and RAMSES (contributions welcome!)
> - Perspective projection for volume rendering
> - Exporting to Sunrise
> - Preliminary particle rendering in volume rendering visualization
> - Drastically improved parallel volume rendering, via kD-tree decomposition
> - Simple merger tree calculation for FOF catalogs
> - New and greatly expanded documentation, with a “source” button

## Version 1.7

> - Direct writing of PNGs
> - Multi-band image writing
> - Parallel halo merger tree (see Halo Merger Tree)
> - Parallel structure function generator (see Two Point Functions)
> - Image pan and zoom object and display widget.
> - Parallel volume rendering (see Volume Rendering: Making 3D Photorealistic Isocontoured Images)
> - Multivariate volume rendering, allowing for multiple forms of emission and absorption, including approximate scattering and Planck emissions. (see Volume Rendering: Making 3D Photorealistic Isocontoured Images)
> - Added Camera interface to volume rendering (See Volume Rendering: Making 3D Photorealistic Isocontoured Images)
> - Off-axis projection (See Volume Rendering: Making 3D Photorealistic Isocontoured Images)
> - Stereo (toe-in) volume rendering (See Volume Rendering: Making 3D Photorealistic Isocontoured Images)
> - DualEPS extension for better EPS construction
> - yt now uses Distribute instead of SetupTools
> - Better `iyt` initialization for GUI support
> - Rewritten, memory conservative and speed-improved contour finding algorithm
> - Speed improvements to volume rendering
> - Preliminary support for the Tiger code
> - Default colormap is now `algae`
> - Lightweight projection loading with `projload`
> - Improvements to yt.data_objects.time_series
> - Improvements to `yt.extensions.EnzoSimulation` (See Analyzing an Entire Simulation)
> - Removed `direct_ray_cast`
> - Fixed bug causing double data-read in projections
> - Added Cylinder support to ParticleIO
> - Fixes for 1- and 2-D Enzo datasets
> - Preliminary, largely non-functional Gadget support
> - Speed improvements to basic HOP
> - Added physical constants module
> - Beginning to standardize and enforce docstring requirements, changing to `autosummary`-based API documentation.

## Version 1.6.1

> - Critical fixes to ParticleIO
> - Halo mass function fixes for comoving coordinates
> - Fixes to halo finding
> - Fixes to the installation script
> - “yt instinfo” command to report current installation information as well as auto-update some types of installations
> - Optimizations to the volume renderer (2x-26x reported speedups)

## Version 1.6

Version 1.6 is a point release, primarily notable for the new parallel halo finder (see Halo Finding)

> - (New) Parallel HOP ( http://arxiv.org/abs/1001.3411 , Halo Finding )
> - (Beta) Software ray casting and volume rendering (see Volume Rendering: Making 3D Photorealistic Isocontoured Images)
> - Rewritten, faster and better contouring engine for clump identification
> - Spectral Energy Distribution calculation for stellar populations (see Synthetic Spectrum Generator)
> - Optimized data structures such as the index
> - Star particle analysis routines (see Star Particle Analysis)
> - Halo mass function routines
> - Completely rewritten, massively faster and more memory efficient Particle IO
> - Fixes for plots, including normalized phase plots
> - Better collective communication in parallel routines
> - Consolidation of optimized C routines into `amr_utils`
> - Many bug fixes and minor optimizations

## Version 1.5

Version 1.5 features many new improvements, most prominently that of the addition of parallel computing abilities (see Parallel Computation With yt) and generalization for multiple AMR data formats, specifically both Enzo and Orion.

> - Rewritten documentation
> - Fully parallel slices, projections, cutting planes, profiles, quantities
> - Parallel HOP
> - Friends-of-friends halo finder
> - Object storage and serialization
> - Major performance improvements to the clump finder (factor of five)
> - Generalized domain sizes
> - Generalized field info containers
> - Dark Matter-only simulations
> - 1D and 2D simulations
> - Better IO for HDF5 sets
> - Support for the Orion AMR code
> - Spherical re-gridding
> - Halo profiler
> - Disk image stacker
> - Light cone generator
> - Callback interface improved
> - Several new callbacks
> - New data objects – ortho and non-ortho rays, limited ray-tracing
> - Fixed resolution buffers
> - Spectral integrator for CLOUDY data
> - Substantially better interactive interface
> - Performance improvements everywhere
> - Command-line interface to many common tasks
> - Isolated plot handling, independent of PlotCollections

## Version 1.0

> - Initial release!